@@ -16,7 +16,6 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence
 from PIL import Image
 
 from cvat_sdk.api_client import apis, exceptions, models
-from cvat_sdk.core import git
 from cvat_sdk.core.downloading import Downloader
 from cvat_sdk.core.helpers import get_paginated_collection
 from cvat_sdk.core.progress import ProgressReporter
@@ -96,6 +95,7 @@ class Task(
                     "job_file_mapping",
                     "filename_pattern",
                     "cloud_storage_id",
+                    "server_files_exclude",
                 ],
             )
         )
@@ -220,6 +220,7 @@ class Task(
         self,
         frame_ids: Sequence[int],
         *,
+        image_extension: Optional[str] = None,
         outdir: StrPath = ".",
         quality: str = "original",
         filename_pattern: str = "frame_{frame_id:06d}{frame_ext}",
@@ -227,23 +228,25 @@ class Task(
         """
         Download the requested frame numbers for a task and save images as outdir/filename_pattern
         """
-        # TODO: add arg descriptions in schema
 
         outdir = Path(outdir)
-        outdir.mkdir(exist_ok=True)
+        outdir.mkdir(parents=True, exist_ok=True)
 
         for frame_id in frame_ids:
             frame_bytes = self.get_frame(frame_id, quality=quality)
 
             im = Image.open(frame_bytes)
-            mime_type = im.get_format_mimetype() or "image/jpg"
-            im_ext = mimetypes.guess_extension(mime_type)
+            if image_extension is None:
+                mime_type = im.get_format_mimetype() or "image/jpg"
+                im_ext = mimetypes.guess_extension(mime_type)
 
-            # FIXME It is better to use meta information from the server
-            # to determine the extension
-            # replace '.jpe' or '.jpeg' with a more used '.jpg'
-            if im_ext in (".jpe", ".jpeg", None):
-                im_ext = ".jpg"
+                # FIXME It is better to use meta information from the server
+                # to determine the extension
+                # replace '.jpe' or '.jpeg' with a more used '.jpg'
+                if im_ext in (".jpe", ".jpeg", None):
+                    im_ext = ".jpg"
+            else:
+                im_ext = f".{image_extension.strip('.')}"
 
             outfile = filename_pattern.format(frame_id=frame_id, frame_ext=im_ext)
             im.save(outdir / outfile)
@@ -348,8 +351,6 @@ class TasksRepo(
         annotation_path: str = "",
         annotation_format: str = "CVAT XML 1.1",
         status_check_period: int = None,
-        dataset_repository_url: str = "",
-        use_lfs: bool = False,
         pbar: Optional[ProgressReporter] = None,
     ) -> Task:
         """
@@ -380,15 +381,6 @@ class TasksRepo(
         if annotation_path:
             task.import_annotations(annotation_format, annotation_path, pbar=pbar)
 
-        if dataset_repository_url:
-            git.create_git_repo(
-                self._client,
-                task_id=task.id,
-                repo_url=dataset_repository_url,
-                status_check_period=status_check_period,
-                use_lfs=use_lfs,
-            )
-
         task.fetch()
 
         return task
@@ -449,6 +441,6 @@ class TasksRepo(
         )
 
         task_id = json.loads(response.data)["id"]
-        self._client.logger.info(f"Task has been imported sucessfully. Task ID: {task_id}")
+        self._client.logger.info(f"Task has been imported successfully. Task ID: {task_id}")
 
         return self.retrieve(task_id)
